Package: mixedBayes
Type: Package
Title: Bayesian Longitudinal Regularized Quantile Mixed Model
Version: 0.2.5
Date: 2026-04-23
Authors@R: c( person("Kun", "Fan", role = c("aut", "cre") , email = "fzt0428@gmail.com"),
              person("Shejuty", "Devnath", role = "aut"),
              person("Cen", "Wu", role = "aut"))
Description: With high-dimensional omics features, repeated measure ANOVA leads to longitudinal gene-environment interaction studies that have intra-cluster correlations, outlying observations and structured sparsity arising from the ANOVA design. In this package, we have developed robust sparse Bayesian mixed effect models tailored for the above studies (Fan et al. (2025) <doi:10.1093/jrsssc/qlaf027>). An efficient Gibbs sampler has been developed to facilitate fast computation. The Markov chain Monte Carlo algorithms of the proposed and alternative methods are efficiently implemented in 'C++'. The development of this software package and the associated statistical methods have been partially supported by an Innovative Research Award from Johnson Cancer Research Center, Kansas State University.
Depends: R (>= 4.2.0)
License: GPL-2
Encoding: UTF-8
URL: https://github.com/kunfa/mixedBayes
BugReports: https://github.com/kunfa/mixedBayes/issues
Imports: Rcpp
LinkingTo: Rcpp, RcppArmadillo
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2026-04-23 06:13:25 UTC; kunfan
Author: Kun Fan [aut, cre],
  Shejuty Devnath [aut],
  Cen Wu [aut]
Maintainer: Kun Fan <fzt0428@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-23 06:30:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-04-23 06:47:50 UTC; unix
Archs: mixedBayes.so.dSYM
