# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

BGL <- function(y, e, g, w, q, o, k, maxSteps, hatM, hatR0, hatRStar, hatAta, z, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, a0, b0, aStar, bStar, Phi1Sq, Phi2Sq, alpha, gamma, alpha1, gamma1, progress) {
    .Call(`_mixedBayes_BGL`, y, e, g, w, q, o, k, maxSteps, hatM, hatR0, hatRStar, hatAta, z, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, a0, b0, aStar, bStar, Phi1Sq, Phi2Sq, alpha, gamma, alpha1, gamma1, progress)
}

BGL_1 <- function(y, e, g, w, q, o, k, maxSteps, hatM, hatR0, hatRStar, hatAta, z, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, a0, b0, aStar, bStar, Phi1Sq, alpha, gamma, alpha1, gamma1, progress) {
    .Call(`_mixedBayes_BGL_1`, y, e, g, w, q, o, k, maxSteps, hatM, hatR0, hatRStar, hatAta, z, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, a0, b0, aStar, bStar, Phi1Sq, alpha, gamma, alpha1, gamma1, progress)
}

BGLSS <- function(y, e, g, w, z, q, o, k, maxSteps, hatM, hatR0, hatAta, hatRStar, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatPi0, hatPiStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, Phi1Sq, Phi2Sq, a0, b0, aStar, bStar, alpha, gamma, alpha1, gamma1, mu0, muStar, nu0, nuStar, progress) {
    .Call(`_mixedBayes_BGLSS`, y, e, g, w, z, q, o, k, maxSteps, hatM, hatR0, hatAta, hatRStar, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatPi0, hatPiStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, Phi1Sq, Phi2Sq, a0, b0, aStar, bStar, alpha, gamma, alpha1, gamma1, mu0, muStar, nu0, nuStar, progress)
}

BGLSS_1 <- function(y, e, g, w, z, q, o, k, maxSteps, hatM, hatR0, hatAta, hatRStar, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatPi0, hatPiStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, Phi1Sq, a0, b0, aStar, bStar, alpha, gamma, alpha1, gamma1, mu0, muStar, nu0, nuStar, progress) {
    .Call(`_mixedBayes_BGLSS_1`, y, e, g, w, z, q, o, k, maxSteps, hatM, hatR0, hatAta, hatRStar, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatPi0, hatPiStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, Phi1Sq, a0, b0, aStar, bStar, alpha, gamma, alpha1, gamma1, mu0, muStar, nu0, nuStar, progress)
}

BL <- function(y, e, g, w, q, k, maxSteps, hatAlpha, hatBeta, hatEta, hatAta, z, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, a0, b0, aStar, bStar, Phi1Sq, Phi2Sq, alpha, gamma, alpha1, gamma1, progress) {
    .Call(`_mixedBayes_BL`, y, e, g, w, q, k, maxSteps, hatAlpha, hatBeta, hatEta, hatAta, z, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, a0, b0, aStar, bStar, Phi1Sq, Phi2Sq, alpha, gamma, alpha1, gamma1, progress)
}

BL_1 <- function(y, e, g, w, q, k, maxSteps, hatAlpha, hatBeta, hatEta, hatAta, z, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, a0, b0, aStar, bStar, Phi1Sq, alpha, gamma, alpha1, gamma1, progress) {
    .Call(`_mixedBayes_BL_1`, y, e, g, w, q, k, maxSteps, hatAlpha, hatBeta, hatEta, hatAta, z, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, a0, b0, aStar, bStar, Phi1Sq, alpha, gamma, alpha1, gamma1, progress)
}

BLSS <- function(y, e, g, w, z, q, k, maxSteps, hatAlpha, hatBeta, hatAta, hatEta, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatPi0, hatPiStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, Phi1Sq, Phi2Sq, a0, b0, aStar, bStar, alpha, gamma, alpha1, gamma1, mu0, muStar, nu0, nuStar, progress) {
    .Call(`_mixedBayes_BLSS`, y, e, g, w, z, q, k, maxSteps, hatAlpha, hatBeta, hatAta, hatEta, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatPi0, hatPiStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, Phi1Sq, Phi2Sq, a0, b0, aStar, bStar, alpha, gamma, alpha1, gamma1, mu0, muStar, nu0, nuStar, progress)
}

BLSS_1 <- function(y, e, g, w, z, q, k, maxSteps, hatAlpha, hatBeta, hatAta, hatEta, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatPi0, hatPiStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, Phi1Sq, a0, b0, aStar, bStar, alpha, gamma, alpha1, gamma1, mu0, muStar, nu0, nuStar, progress) {
    .Call(`_mixedBayes_BLSS_1`, y, e, g, w, z, q, k, maxSteps, hatAlpha, hatBeta, hatAta, hatEta, hatInvSigM0, hatInvTauSq0, hatInvTauSqStar, hatPi0, hatPiStar, hatLambdaSq0, hatLambdaSqStar, hatSigmaSq, Phi1Sq, a0, b0, aStar, bStar, alpha, gamma, alpha1, gamma1, mu0, muStar, nu0, nuStar, progress)
}

RBGL <- function(y, e, g, w, maxSteps, q, o, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, Phi2Sq, a, b, alpha1, gamma1, progress) {
    .Call(`_mixedBayes_RBGL`, y, e, g, w, maxSteps, q, o, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, Phi2Sq, a, b, alpha1, gamma1, progress)
}

RBGL_1 <- function(y, e, g, w, maxSteps, q, o, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, a, b, alpha1, gamma1, progress) {
    .Call(`_mixedBayes_RBGL_1`, y, e, g, w, maxSteps, q, o, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, a, b, alpha1, gamma1, progress)
}

RBGLSS <- function(y, e, g, w, maxSteps, q, o, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatPi1, hatPi2, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, Phi2Sq, a, b, alpha1, gamma1, sh1, sh0, progress) {
    .Call(`_mixedBayes_RBGLSS`, y, e, g, w, maxSteps, q, o, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatPi1, hatPi2, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, Phi2Sq, a, b, alpha1, gamma1, sh1, sh0, progress)
}

RBGLSS_1 <- function(y, e, g, w, maxSteps, q, o, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatPi1, hatPi2, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, a, b, alpha1, gamma1, sh1, sh0, progress) {
    .Call(`_mixedBayes_RBGLSS_1`, y, e, g, w, maxSteps, q, o, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatPi1, hatPi2, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, a, b, alpha1, gamma1, sh1, sh0, progress)
}

RBL <- function(y, e, g, w, maxSteps, q, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, Phi2Sq, a, b, alpha1, gamma1, progress) {
    .Call(`_mixedBayes_RBL`, y, e, g, w, maxSteps, q, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, Phi2Sq, a, b, alpha1, gamma1, progress)
}

RBL_1 <- function(y, e, g, w, maxSteps, q, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, a, b, alpha1, gamma1, progress) {
    .Call(`_mixedBayes_RBL_1`, y, e, g, w, maxSteps, q, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, a, b, alpha1, gamma1, progress)
}

RBLSS <- function(y, e, g, w, maxSteps, q, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatPi1, hatPi2, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, Phi2Sq, a, b, alpha1, gamma1, sh1, sh0, progress) {
    .Call(`_mixedBayes_RBLSS`, y, e, g, w, maxSteps, q, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatPi1, hatPi2, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, Phi2Sq, a, b, alpha1, gamma1, sh1, sh0, progress)
}

RBLSS_1 <- function(y, e, g, w, maxSteps, q, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatPi1, hatPi2, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, a, b, alpha1, gamma1, sh1, sh0, progress) {
    .Call(`_mixedBayes_RBLSS_1`, y, e, g, w, maxSteps, q, k, hatBeta, hatEta, hatAlpha, hatAta, z, hatTau, hatV, hatSg1, hatSg2, invSigAlpha0, hatPi1, hatPi2, hatEtaSq1, hatEtaSq2, xi1, xi2, r1, r2, Phi1Sq, a, b, alpha1, gamma1, sh1, sh0, progress)
}

